@@ -1,6 +1,5 @@
 # coding: utf8
 
-from datetime import timedelta
 import logging
 
 from django import forms
@@ -163,13 +162,6 @@ class RegistrationForm(forms.Form):
             return user
 
         elif getattr(settings, 'ACCOUNT_ACTIVATION_ENABLED', True):
-            key_expiration = now() + timedelta(
-                days=getattr(settings, 'ACCOUNT_ACTIVATION_DAYS', 7)
-            )
-
-            key = ActivationKey.objects.create(
-                user=user, expires=key_expiration
-            )
-            key.send_email()
+            key = user.send_activation_key()
 
             return user, key
